@@ -12,22 +12,12 @@ This module provides the `api_setting` object, that is used to access
 KEAP settings, checking for user settings first, then falling
 back to the defaults.
 """
-from .module_loading import import_string
-from pathlib import Path
-import glob
-BASE_DIR = Path(__file__).parent.parent.parent.parent.parent.parent.resolve()
-
-creds_search = glob.glob(str(BASE_DIR) + '/**/keap-credentials.json', recursive=True)
-if len(creds_search) > 0:
-    KEAP_CREDENTIALS = creds_search[0]
-else:
-    KEAP_CREDENTIALS = './keap-credentials.json'
 
 django_imported = False
 try:
     from django.conf import settings
     from django.test.signals import setting_changed
-    # from django.utils.module_loading import import_string
+    from django.utils.module_loading import import_string
     from django.core.exceptions import ImproperlyConfigured
 
     try:
@@ -35,8 +25,17 @@ try:
         django_imported = True
     except ImproperlyConfigured as e:
         settings = None
-except ImportError as e:
+except ImportError as ie:
     settings = None
+except NameError as ne:
+    settings = None
+
+if not django_imported:
+
+    def import_string(val):
+        components = val.split('.')
+        mod = __import__('.'.join(components[:-1]), fromlist=[components[-1]])
+        return getattr(mod, components[-1])
 
 JSON_STORAGE = 'keap.storages.JSONStorage'
 IN_MEMORY_STORAGE = 'keap.storages.InMemoryStorage'
@@ -56,7 +55,7 @@ DEFAULTS = {
     'USE_DATETIME': True,
 
     'STORAGE_CLASS': 'keap.storages.JSONStorage',
-    'CREDENTIALS_PATH': KEAP_CREDENTIALS,
+    'CREDENTIALS_PATH': './keap-credentials.json',
     'JSON_STORAGE_PATH': './keap-tokens.json',
 
     'APP_NAME': 'default',
